module.exports = defineTest({
	description: 'includes throw statements',
	options: { output: { name: 'myBundle' } }
});
